@@ -1,18 +1,22 @@
-// This is UFC (Unified Form-assembly Code) v. 2.0.5.
+// This is UFC (Unified Form-assembly Code) v. 2.2.0.
 // This code is released into the public domain.
 //
-// The FEniCS Project (http://www.fenicsproject.org/) 2006-2011.
+// The FEniCS Project (http://www.fenicsproject.org/) 2006-2013.
 
 #ifndef __UFC_H
 #define __UFC_H
 
 #define UFC_VERSION_MAJOR 2
-#define UFC_VERSION_MINOR 0
-#define UFC_VERSION_MAINTENANCE 5
+#define UFC_VERSION_MINOR 2
+#define UFC_VERSION_MAINTENANCE 0
 
+#include <vector>
+#include <cstddef>
 #include <stdexcept>
 
-const char UFC_VERSION[] = "2.0.5";
+#include <ufc_geometry.h>
+
+const char UFC_VERSION[] = "2.2.0";
 
 namespace ufc
 {
@@ -20,26 +24,31 @@ namespace ufc
   /// Valid cell shapes
   enum shape {interval, triangle, quadrilateral, tetrahedron, hexahedron};
 
-  /// This class defines the data structure for a finite element mesh.
-
-  class mesh
+  /// This class defines the interface for cell topology data.
+  class cell_topology
   {
   public:
 
-    /// Constructor
-    mesh(): topological_dimension(0), geometric_dimension(0), num_entities(0) {}
+    /// Destructor
+    virtual ~cell_topology() {}
+
+    /// Return array of global entity indices for topological dimension d
+    //virtual const std::size_t* entity_indices(std::size_t d) const;
+
+  };
+
+  /// This class defines the interface for cell geometry data.
+  class cell_geometry
+  {
+  public:
 
     /// Destructor
-    virtual ~mesh() {}
+    virtual ~cell_geometry() {}
 
-    /// Topological dimension of the mesh
-    unsigned int topological_dimension;
+    /// Get vertex coordinates
+    //virtual void get_vertex_coordinates(const double* x[]) const;
 
-    /// Geometric dimension of the mesh
-    unsigned int geometric_dimension;
-
-    /// Array of the global number of entities of each topological dimension
-    unsigned int* num_entities;
+    //virtual std::vector<std::vector<double> >& void vertex_coordinates() const;
 
   };
 
@@ -62,23 +71,29 @@ namespace ufc
     shape cell_shape;
 
     /// Topological dimension of the mesh
-    unsigned int topological_dimension;
+    std::size_t topological_dimension;
 
     /// Geometric dimension of the mesh
-    unsigned int geometric_dimension;
+    std::size_t geometric_dimension;
 
     /// Array of global indices for the mesh entities of the cell
-    unsigned int** entity_indices;
+    std::size_t** entity_indices;
 
     /// Array of coordinates for the vertices of the cell
     double** coordinates;
 
+    // FIXME: Temporary until we remove UFCCell
+    std::vector<double> vertex_coordinates;
+
     /// Cell index (short-cut for entity_indices[topological_dimension][0])
-    unsigned int index;
+    std::size_t index;
 
     /// Local facet index
     int local_facet;
 
+    /// Cell orientation
+    int orientation;
+
     /// Unique mesh identifier
     int mesh_identifier;
 
@@ -90,9 +105,6 @@ namespace ufc
   {
   public:
 
-    /// Constructor
-    function() {}
-
     /// Destructor
     virtual ~function() {}
 
@@ -109,9 +121,6 @@ namespace ufc
   {
   public:
 
-    /// Constructor
-    finite_element() {}
-
     /// Destructor
     virtual ~finite_element() {}
 
@@ -122,57 +131,69 @@ namespace ufc
     virtual shape cell_shape() const = 0;
 
     /// Return the topological dimension of the cell shape
-    virtual unsigned int topological_dimension() const = 0;
+    virtual std::size_t topological_dimension() const = 0;
 
     /// Return the geometric dimension of the cell shape
-    virtual unsigned int geometric_dimension() const = 0;
+    virtual std::size_t geometric_dimension() const = 0;
 
     /// Return the dimension of the finite element function space
-    virtual unsigned int space_dimension() const = 0;
+    virtual std::size_t space_dimension() const = 0;
 
     /// Return the rank of the value space
-    virtual unsigned int value_rank() const = 0;
+    virtual std::size_t value_rank() const = 0;
 
     /// Return the dimension of the value space for axis i
-    virtual unsigned int value_dimension(unsigned int i) const = 0;
+    virtual std::size_t value_dimension(std::size_t i) const = 0;
 
-    /// Evaluate basis function i at given point in cell
-    virtual void evaluate_basis(unsigned int i,
+    /// Evaluate basis function i at given point x in cell
+    virtual void evaluate_basis(std::size_t i,
                                 double* values,
-                                const double* coordinates,
-                                const cell& c) const = 0;
+                                const double* x,
+                                const double* vertex_coordinates,
+                                int cell_orientation) const = 0;
 
-    /// Evaluate all basis functions at given point in cell
+    /// Evaluate all basis functions at given point x in cell
     virtual void evaluate_basis_all(double* values,
-                                    const double* coordinates,
-                                    const cell& c) const = 0;
+                                    const double* x,
+                                    const double* vertex_coordinates,
+                                    int cell_orientation) const = 0;
 
-    /// Evaluate order n derivatives of basis function i at given point in cell
-    virtual void evaluate_basis_derivatives(unsigned int i,
-                                            unsigned int n,
+    /// Evaluate order n derivatives of basis function i at given point x in cell
+    virtual void evaluate_basis_derivatives(std::size_t i,
+                                            std::size_t n,
                                             double* values,
-                                            const double* coordinates,
-                                            const cell& c) const = 0;
+                                            const double* x,
+                                            const double* vertex_coordinates,
+                                            int cell_orientation) const = 0;
 
-    /// Evaluate order n derivatives of all basis functions at given point in cell
-    virtual void evaluate_basis_derivatives_all(unsigned int n,
+    /// Evaluate order n derivatives of all basis functions at given point x in cell
+    virtual void evaluate_basis_derivatives_all(std::size_t n,
                                                 double* values,
-                                                const double* coordinates,
-                                                const cell& c) const = 0;
+                                                const double* x,
+                                                const double* vertex_coordinates,
+                                                int cell_orientation) const = 0;
+
+    // FIXME: cell argument only included here so we can pass it to the eval function...
 
     /// Evaluate linear functional for dof i on the function f
-    virtual double evaluate_dof(unsigned int i,
+    virtual double evaluate_dof(std::size_t i,
                                 const function& f,
+                                const double* vertex_coordinates,
+                                int cell_orientation,
                                 const cell& c) const = 0;
 
     /// Evaluate linear functionals for all dofs on the function f
     virtual void evaluate_dofs(double* values,
                                const function& f,
+                               const double* vertex_coordinates,
+                               int cell_orientation,
                                const cell& c) const = 0;
 
     /// Interpolate vertex values from dof values
     virtual void interpolate_vertex_values(double* vertex_values,
                                            const double* dof_values,
+                                           const double* vertex_coordinates,
+                                           int cell_orientation,
                                            const cell& c) const = 0;
 
     /// Map coordinate xhat from reference cell to coordinate x in cell
@@ -186,10 +207,10 @@ namespace ufc
                                        const cell& c) const = 0;
 
     /// Return the number of sub elements (for a mixed element)
-    virtual unsigned int num_sub_elements() const = 0;
+    virtual std::size_t num_sub_elements() const = 0;
 
     /// Create a new finite element for sub element i (for a mixed element)
-    virtual finite_element* create_sub_element(unsigned int i) const = 0;
+    virtual finite_element* create_sub_element(std::size_t i) const = 0;
 
     /// Create a new class instance
     virtual finite_element* create() const = 0;
@@ -203,9 +224,6 @@ namespace ufc
   {
   public:
 
-    /// Constructor
-    dofmap() {}
-
     /// Destructor
     virtual ~dofmap() {}
 
@@ -213,61 +231,52 @@ namespace ufc
     virtual const char* signature() const = 0;
 
     /// Return true iff mesh entities of topological dimension d are needed
-    virtual bool needs_mesh_entities(unsigned int d) const = 0;
-
-    /// Initialize dofmap for mesh (return true iff init_cell() is needed)
-    virtual bool init_mesh(const mesh& mesh) = 0;
-
-    /// Initialize dofmap for given cell
-    virtual void init_cell(const mesh& m,
-                           const cell& c) = 0;
-
-    /// Finish initialization of dofmap for cells
-    virtual void init_cell_finalize() = 0;
+    virtual bool needs_mesh_entities(std::size_t d) const = 0;
 
     /// Return the topological dimension of the associated cell shape
-    virtual unsigned int topological_dimension() const = 0;
+    virtual std::size_t topological_dimension() const = 0;
 
     /// Return the geometric dimension of the associated cell shape
-    virtual unsigned int geometric_dimension() const = 0;
+    virtual std::size_t geometric_dimension() const = 0;
 
     /// Return the dimension of the global finite element function space
-    virtual unsigned int global_dimension() const = 0;
+    virtual std::size_t global_dimension(const std::vector<std::size_t>&
+                                         num_global_mesh_entities) const = 0;
 
     /// Return the dimension of the local finite element function space for a cell
-    virtual unsigned int local_dimension(const cell& c) const = 0;
+    virtual std::size_t local_dimension(const cell& c) const = 0;
 
     /// Return the maximum dimension of the local finite element function space
-    virtual unsigned int max_local_dimension() const = 0;
+    virtual std::size_t max_local_dimension() const = 0;
 
     /// Return the number of dofs on each cell facet
-    virtual unsigned int num_facet_dofs() const = 0;
+    virtual std::size_t num_facet_dofs() const = 0;
 
     /// Return the number of dofs associated with each cell entity of dimension d
-    virtual unsigned int num_entity_dofs(unsigned int d) const = 0;
+    virtual std::size_t num_entity_dofs(std::size_t d) const = 0;
 
     /// Tabulate the local-to-global mapping of dofs on a cell
-    virtual void tabulate_dofs(unsigned int* dofs,
-                               const mesh& m,
+    virtual void tabulate_dofs(std::size_t* dofs,
+                               const std::vector<std::size_t>& num_global_entities,
                                const cell& c) const = 0;
 
     /// Tabulate the local-to-local mapping from facet dofs to cell dofs
-    virtual void tabulate_facet_dofs(unsigned int* dofs,
-                                     unsigned int facet) const = 0;
+    virtual void tabulate_facet_dofs(std::size_t* dofs,
+                                     std::size_t facet) const = 0;
 
     /// Tabulate the local-to-local mapping of dofs on entity (d, i)
-    virtual void tabulate_entity_dofs(unsigned int* dofs,
-                                      unsigned int d, unsigned int i) const = 0;
+    virtual void tabulate_entity_dofs(std::size_t* dofs,
+                                      std::size_t d, std::size_t i) const = 0;
 
     /// Tabulate the coordinates of all dofs on a cell
-    virtual void tabulate_coordinates(double** coordinates,
-                                      const cell& c) const = 0;
+    virtual void tabulate_coordinates(double** dof_coordinates,
+                                      const double* vertex_coordinates) const = 0;
 
     /// Return the number of sub dofmaps (for a mixed element)
-    virtual unsigned int num_sub_dofmaps() const = 0;
+    virtual std::size_t num_sub_dofmaps() const = 0;
 
     /// Create a new dofmap for sub dofmap i (for a mixed element)
-    virtual dofmap* create_sub_dofmap(unsigned int i) const = 0;
+    virtual dofmap* create_sub_dofmap(std::size_t i) const = 0;
 
     /// Create a new class instance
     virtual dofmap* create() const = 0;
@@ -282,25 +291,20 @@ namespace ufc
   {
   public:
 
-    /// Constructor
-    cell_integral() {}
-
     /// Destructor
     virtual ~cell_integral() {}
 
     /// Tabulate the tensor for the contribution from a local cell
     virtual void tabulate_tensor(double* A,
                                  const double * const * w,
-                                 const cell& c) const = 0;
+                                 const double* vertex_coordinates,
+                                 int cell_orientation) const = 0;
 
+    // FIXME: New experimental version
     /// Tabulate the tensor for the contribution from a local cell
-    /// using the specified reference cell quadrature points/weights
-    virtual void tabulate_tensor(double* A,
-                                 const double * const * w,
-                                 const cell& c,
-                                 unsigned int num_quadrature_points,
-                                 const double * const * quadrature_points,
-                                 const double* quadrature_weights) const = 0;
+    virtual void tabulate_tensor_new(double* A,
+                                     const double * const * w,
+                                     const cell_geometry& c) const {}
 
   };
 
@@ -312,26 +316,14 @@ namespace ufc
   {
   public:
 
-    /// Constructor
-    exterior_facet_integral() {}
-
     /// Destructor
     virtual ~exterior_facet_integral() {}
 
     /// Tabulate the tensor for the contribution from a local exterior facet
     virtual void tabulate_tensor(double* A,
                                  const double * const * w,
-                                 const cell& c,
-                                 unsigned int facet) const = 0;
-
-    /// Tabulate the tensor for the contribution from a local exterior facet
-    /// using the specified reference cell quadrature points/weights
-    virtual void tabulate_tensor(double* A,
-                                 const double * const * w,
-                                 const cell& c,
-                                 unsigned int num_quadrature_points,
-                                 const double * const * quadrature_points,
-                                 const double* quadrature_weights) const = 0;
+                                 const double* vertex_coordinates,
+                                 std::size_t facet) const = 0;
 
   };
 
@@ -343,28 +335,37 @@ namespace ufc
   {
   public:
 
-    /// Constructor
-    interior_facet_integral() {}
-
     /// Destructor
     virtual ~interior_facet_integral() {}
 
     /// Tabulate the tensor for the contribution from a local interior facet
     virtual void tabulate_tensor(double* A,
                                  const double * const * w,
-                                 const cell& c0,
-                                 const cell& c1,
-                                 unsigned int facet0,
-                                 unsigned int facet1) const = 0;
+                                 const double* vertex_coordinates_0,
+                                 const double* vertex_coordinates_1,
+                                 std::size_t facet_0,
+                                 std::size_t facet_1) const = 0;
 
-    /// Tabulate the tensor for the contribution from a local interior facet
-    /// using the specified reference cell quadrature points/weights
+  };
+
+  /// This class defines the interface for the tabulation of
+  /// an expression evaluated at exactly one point.
+
+  class point_integral
+  {
+  public:
+
+    /// Constructor
+    point_integral() {}
+
+    /// Destructor
+    virtual ~point_integral() {}
+
+    /// Tabulate the tensor for the contribution from the local vertex
     virtual void tabulate_tensor(double* A,
                                  const double * const * w,
-                                 const cell& c,
-                                 unsigned int num_quadrature_points,
-                                 const double * const * quadrature_points,
-                                 const double* quadrature_weights) const = 0;
+                                 const double* vertex_coordinates,
+                                 std::size_t vertex) const = 0;
 
   };
 
@@ -387,9 +388,6 @@ namespace ufc
   {
   public:
 
-    /// Constructor
-    form() {}
-
     /// Destructor
     virtual ~form() {}
 
@@ -397,36 +395,68 @@ namespace ufc
     virtual const char* signature() const = 0;
 
     /// Return the rank of the global tensor (r)
-    virtual unsigned int rank() const = 0;
+    virtual std::size_t rank() const = 0;
 
     /// Return the number of coefficients (n)
-    virtual unsigned int num_coefficients() const = 0;
+    virtual std::size_t num_coefficients() const = 0;
 
     /// Return the number of cell domains
-    virtual unsigned int num_cell_domains() const = 0;
+    virtual std::size_t num_cell_domains() const = 0;
 
     /// Return the number of exterior facet domains
-    virtual unsigned int num_exterior_facet_domains() const = 0;
+    virtual std::size_t num_exterior_facet_domains() const = 0;
 
     /// Return the number of interior facet domains
-    virtual unsigned int num_interior_facet_domains() const = 0;
+    virtual std::size_t num_interior_facet_domains() const = 0;
+
+    /// Return the number of point domains
+    virtual std::size_t num_point_domains() const = 0;
+
+    /// Return whether form has any cell integrals
+    virtual bool has_cell_integrals() const = 0;
+
+    /// Return whether form has any exterior facet integrals
+    virtual bool has_exterior_facet_integrals() const = 0;
+
+    /// Return whether form has any interior facet integrals
+    virtual bool has_interior_facet_integrals() const = 0;
+
+    /// Return whether form has any point integrals
+    virtual bool has_point_integrals() const = 0;
 
     /// Create a new finite element for argument function i
-    virtual finite_element* create_finite_element(unsigned int i) const = 0;
+    virtual finite_element* create_finite_element(std::size_t i) const = 0;
 
     /// Create a new dofmap for argument function i
-    virtual dofmap* create_dofmap(unsigned int i) const = 0;
+    virtual dofmap* create_dofmap(std::size_t i) const = 0;
 
     /// Create a new cell integral on sub domain i
-    virtual cell_integral* create_cell_integral(unsigned int i) const = 0;
+    virtual cell_integral* create_cell_integral(std::size_t i) const = 0;
 
     /// Create a new exterior facet integral on sub domain i
     virtual exterior_facet_integral*
-    create_exterior_facet_integral(unsigned int i) const = 0;
+    create_exterior_facet_integral(std::size_t i) const = 0;
 
     /// Create a new interior facet integral on sub domain i
     virtual interior_facet_integral*
-    create_interior_facet_integral(unsigned int i) const = 0;
+    create_interior_facet_integral(std::size_t i) const = 0;
+
+    /// Create a new point integral on sub domain i
+    virtual point_integral* create_point_integral(std::size_t i) const = 0;
+
+    /// Create a new cell integral on everywhere else
+    virtual cell_integral* create_default_cell_integral() const = 0;
+
+    /// Create a new exterior facet integral on everywhere else
+    virtual exterior_facet_integral*
+    create_default_exterior_facet_integral() const = 0;
+
+    /// Create a new interior facet integral on everywhere else
+    virtual interior_facet_integral*
+    create_default_interior_facet_integral() const = 0;
+
+    /// Create a new point integral on everywhere else
+    virtual point_integral* create_default_point_integral() const = 0;
 
   };
 
