@@ -1,7 +1,7 @@
-// This is utility code for UFC (Unified Form-assembly Code) v 2.0.5.
+// This is utility code for UFC (Unified Form-assembly Code) v 2.2.0.
 // This code is released into the public domain.
 //
-// The FEniCS Project (http://www.fenicsproject.org/) 2006-2011.
+// The FEniCS Project (http://www.fenicsproject.org/) 2006-2013.
 
 #ifndef __UFC_BENCHMARK_H__
 #define __UFC_BENCHMARK_H__
@@ -38,8 +38,8 @@ std::vector< std::vector<double> > tabulate_interior_facet_integral(const boost:
                                                                     std::vector< std::vector<double> > macro_w,
                                                                     ufc::cell& cell0,
                                                                     ufc::cell& cell1,
-                                                                    int facet0,
-                                                                    int facet1,
+                                                                    int facet_0,
+                                                                    int facet_1,
                                                                     int domain);
 
 #endif
