@@ -1,4 +1,4 @@
-"""Code generation format strings for UFC (Unified Form-assembly Code) v. 2.0.5.
+"""Code generation format strings for UFC (Unified Form-assembly Code) v. 2.2.0.
 
 Three format strings are defined for each of the following UFC classes:
 
@@ -29,22 +29,22 @@ For more information about UFC and the FEniCS project, visit
 
 # -*- coding: utf-8 -*-
 __author__  = "Martin Sandve Alnaes, Anders Logg, Kent-Andre Mardal, Ola Skavhaug, and Hans Petter Langtangen"
-__date__    = "2011-02-21"
-__version__ = "2.0.5"
+__date__    = "2013-03-24"
+__version__ = "2.2.0"
 __license__ = "This code is released into the public domain"
 
 UFC_VERSION_MAJOR = 2
-UFC_VERSION_MINOR = 0
-UFC_VERSION_MAINTENANCE = 5
+UFC_VERSION_MINOR = 2
+UFC_VERSION_MAINTENANCE = 0
 
 UFC_VERSION = __version__
 
-from function import *
-from finite_element import *
-from dofmap import *
-from integrals import *
-from form import *
-from build import build_ufc_module
+from .function import *
+from .finite_element import *
+from .dofmap import *
+from .integrals import *
+from .form import *
+from .build import build_ufc_module
 
 # Check if we should import development/experimental version
 #import os
@@ -70,6 +70,9 @@ templates = {"function_header":                        function_header,
              "interior_facet_integral_header":         interior_facet_integral_header,
              "interior_facet_integral_implementation": interior_facet_integral_implementation,
              "interior_facet_integral_combined":       interior_facet_integral_combined,
+             "point_integral_header":                  point_integral_header,
+             "point_integral_implementation":          point_integral_implementation,
+             "point_integral_combined":                point_integral_combined,
              "form_header":                            form_header,
              "form_implementation":                    form_implementation,
              "form_combined":                          form_combined}
