@@ -1,7 +1,7 @@
-# Code generation format strings for UFC (Unified Form-assembly Code) v. 2.0.5.
+# Code generation format strings for UFC (Unified Form-assembly Code) v. 2.2.0.
 # This code is released into the public domain.
 #
-# The FEniCS Project (http://www.fenicsproject.org/) 2006-2011.
+# The FEniCS Project (http://www.fenicsproject.org/) 2006-2013.
 
 finite_element_combined = """\
 /// This class defines the interface for a finite element.
@@ -35,74 +35,80 @@ public:
   }
 
   /// Return the topological dimension of the cell shape
-  virtual unsigned int topological_dimension() const
+  virtual std::size_t topological_dimension() const
   {
 %(topological_dimension)s
   }
 
   /// Return the geometric dimension of the cell shape
-  virtual unsigned int geometric_dimension() const
+  virtual std::size_t geometric_dimension() const
   {
 %(geometric_dimension)s
   }
 
   /// Return the dimension of the finite element function space
-  virtual unsigned int space_dimension() const
+  virtual std::size_t space_dimension() const
   {
 %(space_dimension)s
   }
 
   /// Return the rank of the value space
-  virtual unsigned int value_rank() const
+  virtual std::size_t value_rank() const
   {
 %(value_rank)s
   }
 
   /// Return the dimension of the value space for axis i
-  virtual unsigned int value_dimension(unsigned int i) const
+  virtual std::size_t value_dimension(std::size_t i) const
   {
 %(value_dimension)s
   }
 
-  /// Evaluate basis function i at given point in cell
-  virtual void evaluate_basis(unsigned int i,
+  /// Evaluate basis function i at given point x in cell
+  virtual void evaluate_basis(std::size_t i,
                               double* values,
-                              const double* coordinates,
-                              const ufc::cell& c) const
+                              const double* x,
+                              const double* vertex_coordinates,
+                              int cell_orientation) const
   {
 %(evaluate_basis)s
   }
 
-  /// Evaluate all basis functions at given point in cell
+  /// Evaluate all basis functions at given point x in cell
   virtual void evaluate_basis_all(double* values,
-                                  const double* coordinates,
-                                  const ufc::cell& c) const
+                                  const double* x,
+                                  const double* vertex_coordinates,
+                                  int cell_orientation) const
   {
 %(evaluate_basis_all)s
   }
 
-  /// Evaluate order n derivatives of basis function i at given point in cell
-  virtual void evaluate_basis_derivatives(unsigned int i,
-                                          unsigned int n,
+  /// Evaluate order n derivatives of basis function i at given point x in cell
+  virtual void evaluate_basis_derivatives(std::size_t i,
+                                          std::size_t n,
                                           double* values,
-                                          const double* coordinates,
-                                          const ufc::cell& c) const
+                                          const double* x,
+                                          const double* vertex_coordinates,
+                                          int cell_orientation) const
   {
 %(evaluate_basis_derivatives)s
   }
 
-  /// Evaluate order n derivatives of all basis functions at given point in cell
-  virtual void evaluate_basis_derivatives_all(unsigned int n,
+  /// Evaluate order n derivatives of all basis functions at given point x in cell
+  virtual void evaluate_basis_derivatives_all(std::size_t n,
                                               double* values,
-                                              const double* coordinates,
-                                              const ufc::cell& c) const
+                                              const double* x,
+                                              const double* vertex_coordinates,
+                                              int cell_orientation) const
   {
 %(evaluate_basis_derivatives_all)s
   }
 
   /// Evaluate linear functional for dof i on the function f
-  virtual double evaluate_dof(unsigned int i,
+  virtual double evaluate_dof(std::size_t i,
                               const ufc::function& f,
+                              const double* vertex_coordinates,
+                              int cell_orientation,
                               const ufc::cell& c) const
   {
 %(evaluate_dof)s
@@ -111,6 +117,8 @@ public:
   /// Evaluate linear functionals for all dofs on the function f
   virtual void evaluate_dofs(double* values,
                              const ufc::function& f,
+                             const double* vertex_coordinates,
+                             int cell_orientation,
                              const ufc::cell& c) const
   {
 %(evaluate_dofs)s
@@ -119,6 +127,8 @@ public:
   /// Interpolate vertex values from dof values
   virtual void interpolate_vertex_values(double* vertex_values,
                                          const double* dof_values,
+                                         const double* vertex_coordinates,
+                                         int cell_orientation,
                                          const ufc::cell& c) const
   {
 %(interpolate_vertex_values)s
@@ -141,13 +151,13 @@ public:
   }
 
   /// Return the number of sub elements (for a mixed element)
-  virtual unsigned int num_sub_elements() const
+  virtual std::size_t num_sub_elements() const
   {
 %(num_sub_elements)s
   }
 
   /// Create a new finite element for sub element i (for a mixed element)
-  virtual ufc::finite_element* create_sub_element(unsigned int i) const
+  virtual ufc::finite_element* create_sub_element(std::size_t i) const
   {
 %(create_sub_element)s
   }
@@ -181,57 +191,67 @@ public:
   virtual ufc::shape cell_shape() const;
 
   /// Return the topological dimension of the cell shape
-  virtual unsigned int topological_dimension() const;
+  virtual std::size_t topological_dimension() const;
 
   /// Return the geometric dimension of the cell shape
-  virtual unsigned int geometric_dimension() const;
+  virtual std::size_t geometric_dimension() const;
 
   /// Return the dimension of the finite element function space
-  virtual unsigned int space_dimension() const;
+  virtual std::size_t space_dimension() const;
 
   /// Return the rank of the value space
-  virtual unsigned int value_rank() const;
+  virtual std::size_t value_rank() const;
 
   /// Return the dimension of the value space for axis i
-  virtual unsigned int value_dimension(unsigned int i) const;
+  virtual std::size_t value_dimension(std::size_t i) const;
 
-  /// Evaluate basis function i at given point in cell
-  virtual void evaluate_basis(unsigned int i,
+  /// Evaluate basis function i at given point x in cell
+  virtual void evaluate_basis(std::size_t i,
                               double* values,
-                              const double* coordinates,
-                              const ufc::cell& c) const;
+                              const double* x,
+                              const double* vertex_coordinates,
+                              int cell_orientation) const;
 
-  /// Evaluate all basis functions at given point in cell
+  /// Evaluate all basis functions at given point x in cell
   virtual void evaluate_basis_all(double* values,
-                                  const double* coordinates,
-                                  const ufc::cell& c) const;
+                                  const double* x,
+                                  const double* vertex_coordinates,
+                                  int cell_orientation) const;
 
-  /// Evaluate order n derivatives of basis function i at given point in cell
-  virtual void evaluate_basis_derivatives(unsigned int i,
-                                          unsigned int n,
+  /// Evaluate order n derivatives of basis function i at given point x in cell
+  virtual void evaluate_basis_derivatives(std::size_t i,
+                                          std::size_t n,
                                           double* values,
-                                          const double* coordinates,
-                                          const ufc::cell& c) const;
+                                          const double* x,
+                                          const double* vertex_coordinates,
+                                          int cell_orientation) const;
 
-  /// Evaluate order n derivatives of all basis functions at given point in cell
-  virtual void evaluate_basis_derivatives_all(unsigned int n,
+  /// Evaluate order n derivatives of all basis functions at given point x in cell
+  virtual void evaluate_basis_derivatives_all(std::size_t n,
                                               double* values,
-                                              const double* coordinates,
-                                              const ufc::cell& c) const;
+                                              const double* x,
+                                              const double* vertex_coordinates,
+                                              int cell_orientation) const;
 
   /// Evaluate linear functional for dof i on the function f
-  virtual double evaluate_dof(unsigned int i,
+  virtual double evaluate_dof(std::size_t i,
                               const ufc::function& f,
+                              const double* vertex_coordinates,
+                              int cell_orientation,
                               const ufc::cell& c) const;
 
   /// Evaluate linear functionals for all dofs on the function f
   virtual void evaluate_dofs(double* values,
                              const ufc::function& f,
+                             const double* vertex_coordinates,
+                             int cell_orientation,
                              const ufc::cell& c) const;
 
   /// Interpolate vertex values from dof values
   virtual void interpolate_vertex_values(double* vertex_values,
                                          const double* dof_values,
+                                         const double* vertex_coordinates,
+                                         int cell_orientation,
                                          const ufc::cell& c) const;
 
   /// Map coordinate xhat from reference cell to coordinate x in cell
@@ -245,10 +265,10 @@ public:
                                      const ufc::cell& c) const;
 
   /// Return the number of sub elements (for a mixed element)
-  virtual unsigned int num_sub_elements() const;
+  virtual std::size_t num_sub_elements() const;
 
   /// Create a new finite element for sub element i (for a mixed element)
-  virtual ufc::finite_element* create_sub_element(unsigned int i) const;
+  virtual ufc::finite_element* create_sub_element(std::size_t i) const;
 
   /// Create a new class instance
   virtual ufc::finite_element* create() const;
@@ -283,74 +303,80 @@ ufc::shape %(classname)s::cell_shape() const
 }
 
 /// Return the topological dimension of the cell shape
-unsigned int %(classname)s::topological_dimension() const
+std::size_t %(classname)s::topological_dimension() const
 {
 %(topological_dimension)s
 }
 
 /// Return the geometric dimension of the cell shape
-unsigned int %(classname)s::geometric_dimension() const
+std::size_t %(classname)s::geometric_dimension() const
 {
 %(geometric_dimension)s
 }
 
 /// Return the dimension of the finite element function space
-unsigned int %(classname)s::space_dimension() const
+std::size_t %(classname)s::space_dimension() const
 {
 %(space_dimension)s
 }
 
 /// Return the rank of the value space
-unsigned int %(classname)s::value_rank() const
+std::size_t %(classname)s::value_rank() const
 {
 %(value_rank)s
 }
 
 /// Return the dimension of the value space for axis i
-unsigned int %(classname)s::value_dimension(unsigned int i) const
+std::size_t %(classname)s::value_dimension(std::size_t i) const
 {
 %(value_dimension)s
 }
 
-/// Evaluate basis function i at given point in cell
-void %(classname)s::evaluate_basis(unsigned int i,
+/// Evaluate basis function i at given point x in cell
+void %(classname)s::evaluate_basis(std::size_t i,
                                    double* values,
-                                   const double* coordinates,
-                                   const ufc::cell& c) const
+                                   const double* x,
+                                   const double* vertex_coordinates,
+                                   int cell_orientation) const
 {
 %(evaluate_basis)s
 }
 
-/// Evaluate all basis functions at given point in cell
+/// Evaluate all basis functions at given point x in cell
 void %(classname)s::evaluate_basis_all(double* values,
-                                       const double* coordinates,
-                                       const ufc::cell& c) const
+                                       const double* x,
+                                       const double* vertex_coordinates,
+                                       int cell_orientation) const
 {
 %(evaluate_basis_all)s
 }
 
-/// Evaluate order n derivatives of basis function i at given point in cell
-void %(classname)s::evaluate_basis_derivatives(unsigned int i,
-                                               unsigned int n,
+/// Evaluate order n derivatives of basis function i at given point x in cell
+void %(classname)s::evaluate_basis_derivatives(std::size_t i,
+                                               std::size_t n,
                                                double* values,
-                                               const double* coordinates,
-                                               const ufc::cell& c) const
+                                               const double* x,
+                                               const double* vertex_coordinates,
+                                               int cell_orientation) const
 {
 %(evaluate_basis_derivatives)s
 }
 
-/// Evaluate order n derivatives of all basis functions at given point in cell
-void %(classname)s::evaluate_basis_derivatives_all(unsigned int n,
+/// Evaluate order n derivatives of all basis functions at given point x in cell
+void %(classname)s::evaluate_basis_derivatives_all(std::size_t n,
                                                    double* values,
-                                                   const double* coordinates,
-                                                   const ufc::cell& c) const
+                                                   const double* x,
+                                                   const double* vertex_coordinates,
+                                                   int cell_orientation) const
 {
 %(evaluate_basis_derivatives_all)s
 }
 
 /// Evaluate linear functional for dof i on the function f
-double %(classname)s::evaluate_dof(unsigned int i,
+double %(classname)s::evaluate_dof(std::size_t i,
                                    const ufc::function& f,
+                                   const double* vertex_coordinates,
+                                   int cell_orientation,
                                    const ufc::cell& c) const
 {
 %(evaluate_dof)s
@@ -359,6 +385,8 @@ double %(classname)s::evaluate_dof(unsigned int i,
 /// Evaluate linear functionals for all dofs on the function f
 void %(classname)s::evaluate_dofs(double* values,
                                   const ufc::function& f,
+                                  const double* vertex_coordinates,
+                                  int cell_orientation,
                                   const ufc::cell& c) const
 {
 %(evaluate_dofs)s
@@ -367,6 +395,8 @@ void %(classname)s::evaluate_dofs(double* values,
 /// Interpolate vertex values from dof values
 void %(classname)s::interpolate_vertex_values(double* vertex_values,
                                               const double* dof_values,
+                                              const double* vertex_coordinates,
+                                              int cell_orientation,
                                               const ufc::cell& c) const
 {
 %(interpolate_vertex_values)s
@@ -389,13 +419,13 @@ void %(classname)s::map_to_reference_cell(double* xhat,
 }
 
 /// Return the number of sub elements (for a mixed element)
-unsigned int %(classname)s::num_sub_elements() const
+std::size_t %(classname)s::num_sub_elements() const
 {
 %(num_sub_elements)s
 }
 
 /// Create a new finite element for sub element i (for a mixed element)
-ufc::finite_element* %(classname)s::create_sub_element(unsigned int i) const
+ufc::finite_element* %(classname)s::create_sub_element(std::size_t i) const
 {
 %(create_sub_element)s
 }
