@@ -1,7 +1,7 @@
-# Code generation format strings for UFC (Unified Form-assembly Code) v. 2.0.5.
+# Code generation format strings for UFC (Unified Form-assembly Code) v. 2.2.0.
 # This code is released into the public domain.
 #
-# The FEniCS Project (http://www.fenicsproject.org/) 2006-2011.
+# The FEniCS Project (http://www.fenicsproject.org/) 2006-2013
 
 cell_integral_combined = """\
 /// This class defines the interface for the tabulation of the cell
@@ -27,23 +27,12 @@ public:
   /// Tabulate the tensor for the contribution from a local cell
   virtual void tabulate_tensor(double* A,
                                const double * const * w,
-                               const ufc::cell& c) const
+                               const double* vertex_coordinates,
+                               int cell_orientation) const
   {
 %(tabulate_tensor)s
   }
 
-  /// Tabulate the tensor for the contribution from a local cell
-  /// using the specified reference cell quadrature points/weights
-  virtual void tabulate_tensor(double* A,
-                               const double * const * w,
-                               const ufc::cell& c,
-                               unsigned int num_quadrature_points,
-                               const double * const * quadrature_points,
-                               const double* quadrature_weights) const
-  {
-%(tabulate_tensor_quadrature)s
-  }
-
 };
 """
 
@@ -65,16 +54,8 @@ public:
   /// Tabulate the tensor for the contribution from a local cell
   virtual void tabulate_tensor(double* A,
                                const double * const * w,
-                               const ufc::cell& c) const;
-
-  /// Tabulate the tensor for the contribution from a local cell
-  /// using the specified reference cell quadrature points/weights
-  virtual void tabulate_tensor(double* A,
-                               const double * const * w,
-                               const ufc::cell& c,
-                               unsigned int num_quadrature_points,
-                               const double * const * quadrature_points,
-                               const double* quadrature_weights) const;
+                               const double* vertex_coordinates,
+                               int cell_orientation) const;
 
 };
 """
@@ -95,22 +76,11 @@ cell_integral_implementation = """\
 /// Tabulate the tensor for the contribution from a local cell
 void %(classname)s::tabulate_tensor(double* A,
                                     const double * const * w,
-                                    const ufc::cell& c) const
+                                    const double* vertex_coordinates,
+                                    int cell_orientation) const
 {
 %(tabulate_tensor)s
 }
-
-/// Tabulate the tensor for the contribution from a local cell
-/// using the specified reference cell quadrature points/weights
-void %(classname)s::tabulate_tensor(double* A,
-                     const double * const * w,
-                     const ufc::cell& c,
-                     unsigned int num_quadrature_points,
-                     const double * const * quadrature_points,
-                     const double* quadrature_weights) const
-{
-%(tabulate_tensor_quadrature)s
-}
 """
 
 exterior_facet_integral_combined = """\
@@ -137,24 +107,12 @@ public:
   /// Tabulate the tensor for the contribution from a local exterior facet
   virtual void tabulate_tensor(double* A,
                                const double * const * w,
-                               const ufc::cell& c,
-                               unsigned int facet) const
+                               const double* vertex_coordinates,
+                               std::size_t facet) const
   {
 %(tabulate_tensor)s
   }
 
-  /// Tabulate the tensor for the contribution from a local exterior facet
-  /// using the specified reference cell quadrature points/weights
-  virtual void tabulate_tensor(double* A,
-                               const double * const * w,
-                               const ufc::cell& c,
-                               unsigned int num_quadrature_points,
-                               const double * const * quadrature_points,
-                               const double* quadrature_weights) const
-  {
-%(tabulate_tensor_quadrature)s
-  }
-
 };
 """
 
@@ -176,17 +134,8 @@ public:
   /// Tabulate the tensor for the contribution from a local exterior facet
   virtual void tabulate_tensor(double* A,
                                const double * const * w,
-                               const ufc::cell& c,
-                               unsigned int facet) const;
-
-  /// Tabulate the tensor for the contribution from a local exterior facet
-  /// using the specified reference cell quadrature points/weights
-  virtual void tabulate_tensor(double* A,
-                               const double * const * w,
-                               const ufc::cell& c,
-                               unsigned int num_quadrature_points,
-                               const double * const * quadrature_points,
-                               const double* quadrature_weights) const;
+                               const double* vertex_coordinates,
+                               std::size_t facet) const;
 
 };
 """
@@ -207,23 +156,11 @@ exterior_facet_integral_implementation = """\
 /// Tabulate the tensor for the contribution from a local exterior facet
 void %(classname)s::tabulate_tensor(double* A,
                                     const double * const * w,
-                                    const ufc::cell& c,
-                                    unsigned int facet) const
+                                    const double* vertex_coordinates,
+                                    std::size_t facet) const
 {
 %(tabulate_tensor)s
 }
-
-/// Tabulate the tensor for the contribution from a local exterior facet
-/// using the specified reference cell quadrature points/weights
-void %(classname)s::tabulate_tensor(double* A,
-                     const double * const * w,
-                     const ufc::cell& c,
-                     unsigned int num_quadrature_points,
-                     const double * const * quadrature_points,
-                     const double* quadrature_weights) const
-{
-%(tabulate_tensor_quadrature)s
-}
 """
 
 interior_facet_integral_combined = """\
@@ -250,26 +187,14 @@ public:
   /// Tabulate the tensor for the contribution from a local interior facet
   virtual void tabulate_tensor(double* A,
                                const double * const * w,
-                               const ufc::cell& c0,
-                               const ufc::cell& c1,
-                               unsigned int facet0,
-                               unsigned int facet1) const
+                               const double* vertex_coordinates_0,
+                               const double* vertex_coordinates_1,
+                               std::size_t facet_0,
+                               std::size_t facet_1) const
   {
 %(tabulate_tensor)s
   }
 
-  /// Tabulate the tensor for the contribution from a local interior facet
-  /// using the specified reference cell quadrature points/weights
-  virtual void tabulate_tensor(double* A,
-                               const double * const * w,
-                               const ufc::cell& c,
-                               unsigned int num_quadrature_points,
-                               const double * const * quadrature_points,
-                               const double* quadrature_weights) const
-  {
-%(tabulate_tensor_quadrature)s
-  }
-
 };
 """
 
@@ -291,19 +216,10 @@ public:
   /// Tabulate the tensor for the contribution from a local interior facet
   virtual void tabulate_tensor(double* A,
                                const double * const * w,
-                               const ufc::cell& c0,
-                               const ufc::cell& c1,
-                               unsigned int facet0,
-                               unsigned int facet1) const;
-
-  /// Tabulate the tensor for the contribution from a local interior facet
-  /// using the specified reference cell quadrature points/weights
-  virtual void tabulate_tensor(double* A,
-                               const double * const * w,
-                               const ufc::cell& c,
-                               unsigned int num_quadrature_points,
-                               const double * const * quadrature_points,
-                               const double* quadrature_weights) const;
+                               const double* vertex_coordinates_0,
+                               const double* vertex_coordinates_1,
+                               std::size_t facet_0,
+                               std::size_t facet_1) const;
 
 };
 """
@@ -324,23 +240,89 @@ interior_facet_integral_implementation = """\
 /// Tabulate the tensor for the contribution from a local interior facet
 void %(classname)s::tabulate_tensor(double* A,
                                     const double * const * w,
-                                    const ufc::cell& c0,
-                                    const ufc::cell& c1,
-                                    unsigned int facet0,
-                                    unsigned int facet1) const
+                                    const double* vertex_coordinates_0,
+                                    const double* vertex_coordinates_1,
+                                    std::size_t facet_0,
+                                    std::size_t facet_1) const
 {
 %(tabulate_tensor)s
 }
+"""
 
-/// Tabulate the tensor for the contribution from a local interior facet
-/// using the specified reference cell quadrature points/weights
-void %(classname)s::tabulate_tensor(double* A,
-                     const double * const * w,
-                     const ufc::cell& c,
-                     unsigned int num_quadrature_points,
-                     const double * const * quadrature_points,
-                     const double* quadrature_weights) const
+point_integral_combined = """\
+/// This class defines the interface for the tabulation of
+/// an expression evaluated at exactly one point.
+
+class %(classname)s: public ufc::point_integral
+{%(members)s
+public:
+
+  /// Constructor
+  %(classname)s(%(constructor_arguments)s) : ufc::point_integral()%(initializer_list)s
+  {
+%(constructor)s
+  }
+
+  /// Destructor
+  virtual ~%(classname)s()
+  {
+%(destructor)s
+  }
+
+  /// Tabulate the tensor for the contribution from the local vertex
+  virtual void tabulate_tensor(double* A,
+                               const double * const * w,
+                               const double* vertex_coordinates,
+                               std::size_t vertex) const
+  {
+%(tabulate_tensor)s
+  }
+
+};
+"""
+
+point_integral_header = """\
+/// This class defines the interface for the tabulation of
+/// an expression evaluated at exactly one point.
+
+class %(classname)s: public ufc::point_integral
+{%(members)s
+public:
+
+  /// Constructor
+  %(classname)s(%(constructor_arguments)s);
+
+  /// Destructor
+  virtual ~%(classname)s();
+
+  /// Tabulate the tensor for the contribution from the local vertex
+  virtual void tabulate_tensor(double* A,
+                               const double * const * w,
+                               const double* vertex_coordinates,
+                               std::size_t vertex) const;
+
+};
+"""
+
+point_integral_implementation = """\
+/// Constructor
+%(classname)s::%(classname)s(%(constructor_arguments)s) : ufc::point_integral()%(initializer_list)s
 {
-%(tabulate_tensor_quadrature)s
+%(constructor)s
+}
+
+/// Destructor
+%(classname)s::~%(classname)s()
+{
+%(destructor)s
+}
+
+/// Tabulate the tensor for the contribution from the local vertex
+void %(classname)s::tabulate_tensor(double* A,
+                                    const double * const * w,
+                                    const double* vertex_coordinates,
+                                    std::size_t vertex) const
+{
+%(tabulate_tensor)s
 }
 """
